declare type CommandUniqueId = number;

export declare const complete: {
    repl(payload: CompletePayload): Promise<CompletionResults>;
};

declare type CompletePayload = {
    code: string;
    line?: number;
    column?: number;
};

declare type CompletionMatch = CompletionResult;

declare type CompletionResult = {
    name: string;
    type: string;
    description: string;
    full_name: string;
};

declare type CompletionResults = {
    matches: CompletionMatch[];
};

declare type ComplexPayload = {
    type: PayloadType;
    name: string;
};

declare type Context = Record<string, unknown | ComplexPayload>;

export declare function exec(payload: ExecPayload): Promise<ExecReturnValue>;

declare type ExecPayload = {
    code: string;
    context?: Context;
};

declare type ExecResponse = {
    id: CommandUniqueId;
    error: string | null;
    result: string | null;
    stdout: string | null;
    stderr: string | null;
};

declare type ExecReturnValue = Omit<ExecResponse, 'id'>;

export declare function format(payload: FormatPayload): Promise<FormatReturnValue>;

declare type FormatPayload = {
    code: string;
};

declare type FormatResponse = {
    id: CommandUniqueId;
    result: string | null;
    error: string | null;
};

declare type FormatReturnValue = Omit<FormatResponse, 'id'>;

export declare const init: () => Promise<Worker>;

export declare function install(packages: string[]): Promise<InstallReturnValue>;

declare type InstallResponse = {
    id: CommandUniqueId;
    success: boolean;
    error: string | null;
};

declare type InstallReturnValue = Omit<InstallResponse, 'id'>;

export declare function interrupt(): void;

declare enum PayloadType {
    FN = "__function__"
}

export { }
